# ORKG NLP PyPI
[![Documentation Status](https://readthedocs.org/projects/orkg-nlp-pypi/badge/?version=latest)](https://orkg-nlp-pypi.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/orkgnlp.svg)](https://badge.fury.io/py/orkgnlp)

PyPI package wrapping the ORKG NLP services.

Check our [Read the Docs](https://orkg-nlp-pypi.readthedocs.io/en/latest/) for more details!